@@ -24,6 +24,9 @@ import Language.Haskell.Exts.Syntax
 import Language.Haskell.Exts.Build
 import Control.Applicative (Applicative(pure, (<*>)))
 import Control.Monad       (ap)
+#if MIN_VERSION_base(4,9,0)
+import qualified Control.Monad.Fail as Fail
+#endif
 import Data.List (union)
 
 import Debug.Trace (trace)
@@ -44,6 +47,13 @@ instance Monad HsxM where
                                       (MkHsxM f') = k a
                                    in f' s')
 
+#if MIN_VERSION_base(4,9,0)
+-- this is probably wrong, but should never be called anyway.
+instance Fail.MonadFail HsxM where
+    fail str = error str
+    {-# INLINE fail #-}
+#endif
+
 getHsxState :: HsxM HsxState
 getHsxState = MkHsxM (\s -> (s, s))
 
